@@ -4,7 +4,7 @@ use warnings;
 use base qw{Pod::Parser};
 
 # Set our version
-our $VERSION = '0.0002';
+our $VERSION = '0.001';
 
 # Hold data for our pending statement
 my $info = {};
@@ -23,19 +23,28 @@ our %TT = (
     #~ BROKEN => sub { die @_;},
 );
 
-my %tt = (); # per file/instance Text::Template->new(%TT, %tt)
+my %tt = (); # instance scope: Text::Template->new(..., tt=>{%TT, %tt}, )
+my $tt = {}; # new scope: Text::Template->new(..., tt=>{%TT, %$tt}, )
+my %template = (); # instance scope: Text::Template->new(..., template=>\%template, )
+my $template = {}; # new scope: Text::Template->new(..., template=>$template, )
+my $scope; # 'new' | 'instance'
 
 # separate object
 sub new {
     my ($class, $file, %arg) = @_;
+    $scope = 'new';
     my %back = %sql;
-    my %back_tt = %tt;
-    %tt = %arg;
+    #~ my %back_tt = %tt;
+    
+    $tt = $arg{TT} || $arg{tt} || {};
+    $template = $arg{template} || {};
     %sql = ();
+    
     $class->_process( $file,);
     my $new = { %sql };
+    
     %sql = %back;
-    %tt = %back_tt;
+    #~ %tt = %back_tt;
     bless $new, $class;
 }
 
@@ -53,16 +62,20 @@ sub instance {
 
 sub _instance {
     my ($class, $file, %arg) = @_;
+    $scope = 'instance';
     # merge prev tt opts
-    @tt{ keys %arg } = values %arg; 
+    my $tt = $arg{TT} || $arg{tt};
+    @tt{ keys %$tt } = values %$tt
+        if $tt;
+    @template{ keys %{$arg{template}} } = values %{$arg{template}}
+        if $arg{template};
     $class->_process( $file,);
     bless \%sql, $class;
 }
 
 sub _process {# pos file
     my ($class, $file,) = @_;
-    return 
-        unless $file;
+    return unless $file;
     $file .='.pm'
         if $file =~ s/::/\//g;
     $class->SUPER::new->parse_from_file($file);
@@ -118,7 +131,11 @@ sub end_input {
         #~ if (scalar (grep {m/^(?:name|short|desc|sql)$/} keys %{$info}) == 3) {
         if (defined($info->{name}) && defined($info->{sql})) {
             # Grab the entire content for the %sql hash
-            $sql{$info->{name}} = DBIx::POS::Statement->new ($info, %TT, %tt);
+            $sql{$info->{name}} = DBIx::POS::Statement->new (
+                $info,
+                tt => {%TT, $scope eq 'new' ? %$tt : %tt},
+                template => $scope eq 'new' ? $template : \%template,
+            );
             $sql{$info->{name}}->_eval_param() if $sql{$info->{name}}->param;
             # Start with a new empty hashref
             $info = {};
@@ -175,14 +192,17 @@ sub verbatim {
 package DBIx::POS::Statement;
 #=============================================
 use Text::Template;
+use Hash::Merge qw(merge);
 
-use overload '""' => sub { shift->{sql} };
+use overload '""' => sub { shift->template };
 
 sub new {
     my $proto = shift;
     my $class = ref $proto || $proto;
     my $self = shift;
-    $self->{_TT} = { @_ };
+    my %arg = @_;
+    $self->{_TT} = $arg{TT} || $arg{tt} ;
+    $self->{_template_default} = $arg{template};
     bless ($self, $class);
     return $self;
 }
@@ -208,16 +228,16 @@ sub noreturn {
 sub param {# ->param() |  ->param('foo') | ->param('foo'=>'bar', ....)
     my $self = shift;
     return unless defined $self->{param};
+    #~ $self->{param} ||= {};
+    return $self->{param} unless ref $self->{param} eq 'HASH';
     return $self->{param} unless @_;
     return $self->{param}{shift()} if @_ == 1;
     my %arg = @_;
-    my($key, $value);
-    $self->{param}{ $key } = $value while ($key, $value) = each %arg;
+    @{$self->{param} ||= {}}{ keys %arg } = values %arg;
 }
 
 sub _eval_param {
     my $self = shift;
-    #~ warn "\n---------------\n$self->{param}\n===========\n";
     my $param = eval $self->{param};
     die "Malformed perl code param [$self->{param}]: $@" if $@;
     $self->{param} = $param;
@@ -238,14 +258,19 @@ sub sql {
 
 sub template {
     my ($self, %arg) = @_;
-    return $self->sql
-        unless scalar %arg;
+    return $self->{sql}
+        unless scalar(%arg) || scalar(%{$self->{_template_default}});
     $self->{_template} ||= Text::Template->new(
         TYPE => 'STRING',
-        SOURCE => $self->sql,
+        SOURCE => $self->{sql},
         %{$self->{_TT}},
     );
-    $self->{_template}->fill_in(HASH=>\%arg,);#BROKEN_ARG=>\'error!', BROKEN => sub { die @_;},
+    #~ $self->{_template}->fill_in(HASH=>{%{$self->{_template_default}}, %arg},);#BROKEN_ARG=>\'error!', BROKEN => sub { die @_;},
+    return $self->{_template}->fill_in(HASH=>$self->{_template_default})
+        unless %arg;
+    return $self->{_template}->fill_in(HASH=>\%arg)
+        unless %{$self->{_template_default}};
+    $self->{_template}->fill_in(HASH=>merge(\%arg, $self->{_template_default}));
 }
 
 1;
@@ -263,7 +288,7 @@ sub template {
 
 =head1 VERSION
 
-0.0002
+0.001
 
 =head1 NAME
 
@@ -301,30 +326,7 @@ DBIx::POS::Template - is a fork of L<DBIx::POS>. Define a dictionary of SQL stat
 
   =cut
 
-Or inheritance syntax
 
-  package FooPOS;
-  use base qw{DBIx::POS::Template};
-  
-  sub new { shift->SUPER::new(__FILE__); }
-  
-  =pod
-  
-  =name ...
-  
-  =desc ...
-  
-  ...
-  
-  =cut
-  
-  1;
-
-Then
-
-  use FooPos;
-  my $pos = FooPOS->new;# pos-file is the self module
-  
 
 =head1 DESCRIPTION
 
@@ -348,10 +350,25 @@ This class whould work as separate objects per pod-file or as singleton for all
 
 =head2 new($file, <options>)
 
-Create separate object and process $file POS with options, will passing to Text::Template->new() for each parsed statement. By default only defined option 
+Create separate object and process $file POS with options names:
 
-    DELIMITERS => ['{%', '%}'],
+=over 4
 
+=item * TT | tt
+
+Optional hashref will passing to L<Text::Template>->new() for each parsed statement. By default only defined the key:
+
+  ..., TT => {DELIMITERS => ['{%', '%}'],},
+
+For B<instance> this hashref will be merged with previous instance invokes.
+
+=item * template
+
+  ..., template => {foo=>1,},
+
+Optional hashref of default values for each statement template. For B<instance> this hashref will be merged with previous instance invokes.
+
+=back
 
 =head2 instance($file, <options>)
 
